==> arrow-instances-free-0.8.1-sources.jar: extension/arrow/free/instances/free/functor/FreeFunctorInstance.kt <==
package arrow.free.instances.free.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForFree
import arrow.free.Free
import arrow.free.Free.Companion
import arrow.free.instances.FreeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.map(arg1: Function1<A, B>): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Free<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForFree, S>, A>, Kind<Kind<ForFree, S>, B>> = arrow.free.Free
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForFree, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForFree, S>, B>>

@JvmName("void")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFree, S>, A>.void(): Free<S, Unit> = arrow.free.Free.functor<S>().run {
  this@void.void<A>() as arrow.free.Free<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.fproduct(arg1: Function1<A, B>): Free<S, Tuple2<A, B>> = arrow.free.Free.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.`as`(arg1: B): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.tupleLeft(arg1: B): Free<S, Tuple2<B, A>> = arrow.free.Free.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.tupleRight(arg1: B): Free<S, Tuple2<A, B>> = arrow.free.Free.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForFree, S>, A>.widen(): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.Free<S, B>
}

fun <S> Companion.functor(): FreeFunctorInstance<S> = object : arrow.free.instances.FreeFunctorInstance<S> {  }

==> arrow-instances-free-0.8.2-sources.jar: extension/arrow/free/instances/free/functor/FreeFunctorInstance.kt <==
package arrow.free.instances.free.functor

import arrow.Kind
import arrow.core.Tuple2
import arrow.free.ForFree
import arrow.free.Free
import arrow.free.Free.Companion
import arrow.free.instances.FreeFunctorInstance
import kotlin.Function1
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

@JvmName("map")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.map(arg1: Function1<A, B>): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@map.map<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("imap")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.imap(arg1: Function1<A, B>, arg2: Function1<B, A>): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@imap.imap<A, B>(arg1, arg2) as arrow.free.Free<S, B>
}

@JvmName("lift")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> lift(arg0: Function1<A, B>): Function1<Kind<Kind<ForFree, S>, A>, Kind<Kind<ForFree, S>, B>> = arrow.free.Free
   .functor<S>()
   .lift<A, B>(arg0) as kotlin.Function1<arrow.Kind<arrow.Kind<arrow.free.ForFree, S>, A>, arrow.Kind<arrow.Kind<arrow.free.ForFree, S>, B>>

@JvmName("unit")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A> Kind<Kind<ForFree, S>, A>.unit(): Free<S, Unit> = arrow.free.Free.functor<S>().run {
  this@unit.unit<A>() as arrow.free.Free<S, kotlin.Unit>
}

@JvmName("fproduct")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.fproduct(arg1: Function1<A, B>): Free<S, Tuple2<A, B>> = arrow.free.Free.functor<S>().run {
  this@fproduct.fproduct<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("as")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.`as`(arg1: B): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@`as`.`as`<A, B>(arg1) as arrow.free.Free<S, B>
}

@JvmName("tupleLeft")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.tupleLeft(arg1: B): Free<S, Tuple2<B, A>> = arrow.free.Free.functor<S>().run {
  this@tupleLeft.tupleLeft<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<B, A>>
}

@JvmName("tupleRight")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, A, B> Kind<Kind<ForFree, S>, A>.tupleRight(arg1: B): Free<S, Tuple2<A, B>> = arrow.free.Free.functor<S>().run {
  this@tupleRight.tupleRight<A, B>(arg1) as arrow.free.Free<S, arrow.core.Tuple2<A, B>>
}

@JvmName("widen")
@Suppress(
        "UNCHECKED_CAST",
        "USELESS_CAST",
        "EXTENSION_SHADOWED_BY_MEMBER",
        "UNUSED_PARAMETER"
)
fun <S, B, A : B> Kind<Kind<ForFree, S>, A>.widen(): Free<S, B> = arrow.free.Free.functor<S>().run {
  this@widen.widen<B, A>() as arrow.free.Free<S, B>
}

fun <S> Companion.functor(): FreeFunctorInstance<S> = object : arrow.free.instances.FreeFunctorInstance<S> {  }
